var console = window.console || { log: function () {} };

/** Addons state variables. **/
var stormRepordsEnabled = false;
var stormTracksEnabled = false;
var temperaturesEnabled = false;
var windDirectionsEnabled = false;
var legendEnabled = true;
var stormChasersEnabled = false;
var autoLightningEnable = window.auto_lightning_enable ? true : false;
var lightning_enable = false;
if(typeof(lightning_enable_parameter) != 'undefined'){
	lightning_enable = lightning_enable_parameter;
}

/** Updater variables. **/
var inputUpdateTimeout;

/** Zoom, touch and lock variables. **/
var zoomLevel = 0;
var dragLock = false;
var zoomLock = false;
var touchMoved = false;

/** Checks if there is an animated module. **/
function isAnimating() {
	if (modules) {
		for (var module in modules) {
			if (modules[module].isAnimating) return true;
		}
	}
	return false;
}

/** Prepares location search. **/
function GetMapCoordinate(source, forceRefresh, zoomIncrease) {
	var geocode = new LocationGeocode();
	geocode.forward(address=$(source).val()).then(function(data){
		if(data.length > 0){
			var info = data[0];
			lat = info.lat;
			long = info.lon;
			updateMapOnLocationChange(forceRefresh, zoomIncrease);
			mapZipcode = '';
		}
	})
}

/** Prepares location search via ZIP. **/
function GetMapCoordinateFromZip(source, forceRefresh, zoomIncrease) {
	var zipValue = $(source).val();
	var geocode = new LocationGeocode();
	geocode.forward(zipValue).then(function(data){
		if(data.length > 0){
			var info = data[0];
			lat = info.lat;
			long = info.lon;
			updateMapOnLocationChange(forceRefresh, zoomIncrease);
			mapZipcode = zipValue;
		}
	})
}

// --------------------------------------- EVENTS ------------------------------------------

/** Handles zoom end. **/
function zoomEnd(evt) {
	checkMinZoomLevel();

	for (var module in modules) {
		modules[module].mapZoomed && modules[module].mapZoomed(evt);
	}
	for (var addon in addons) {
		addons[addon].updateFrame();
		addons[addon].mapZoomed && addons[addon].mapZoomed();
	}

	setTimeout(function () {
		for (var module in modules) {
			modules[module].refresh();
		}
	}, 1000);
}

/** Handles drag start. **/
function dragStart(evt) {
	dragLock = true;

	for (var module in modules) {
		modules[module].mapDragStarted && modules[module].mapDragStarted(evt);
	}
	for (var addon in addons) {
		addons[addon].mapDragStarted && addons[addon].mapDragStarted(evt);
	}
}

/** Handles dragging. **/
function dragging() {
}

/** Handles drag end. **/
function dragEnd(evt) {
	dragLock = false;

	for (var module in modules) {
		modules[module].mapDragged && modules[module].mapDragged(evt);
	}
	for (var addon in addons) {
		addons[addon].mapDragged && addons[addon].mapDragged(evt);
	}

	setTimeout(function () {
		for (var module in modules) {
			modules[module].refresh();
		}
	}, 1000);
}

/** Handles drag end. **/
function mapIdle(evt) {
	for (var module in modules) {
		modules[module].mapIdle && modules[module].mapIdle(evt);
	}
	for (var addon in addons) {
		addons[addon].mapIdle && addons[addon].mapIdle(evt);
	}
}

/** Handles touch start. **/
function onMapTouchStart(evt) {
	touchMoved = false;
	event.preventDefault();
	event.stopPropagation();
}

/** Handles touch end. **/
function onMapTouchEnd(evt) {
	if (!touchMoved) {
		var point = {};
		point.x = evt.changedTouches[0].pageX - $("#map").offset().left;
		point.y = evt.changedTouches[0].pageY - $("#map").offset().top;
		addons.severeWarnings && addons.severeWarnings.tryToShowWarningInfo(zr_map.pixToLL(point));
	}

	event.preventDefault();
	event.stopPropagation();
}

/** Handles touch move. **/
function onMapTouchMove(evt) {
	dragging();
	touchMoved = true;
	event.preventDefault();
	event.stopPropagation();
}
// --------------------------------------- END EVENTS ---------------------------------------


function updateMapOnLocationChange(forceRefresh, zoomIncrease, detectLocation) {
	//mapquest has a bug: when map is recreated on ios device, it is irresponsive to touches
	if (forceRefresh && ((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i)) || (navigator.userAgent.match(/iPad/i)))) {
		//window.location = '?w='+map_width+'&h='+map_height+'&z='+map_zoom+'&lat='+lat+'&lng='+long+'&search='+search_enabled+'&warn='+warnings_enabled+(storm_reports_enabled ? '&stormReports=1' : '')+(banner_enabled ? '' : '&hideBanner=1')+(pan_enabled ? '&pan=1' : '&pan=0');
		var url = '?w=' + map_width + '&h=' + map_height
				+ '&z=' + map_zoom
				+ '&lat=' + lat
				+ '&lng=' + long
				+ (pan_enabled ? '&pan=1' : '&pan=0')
				+ (search_enabled ? '&search=1' : '')
				+ (warnings_enabled ? '&warn=1' : '')
				+ (bulletins_enabled ? '&bulletins=1' : '')
				+ (allWarnings_enabled ? '&allWarn=1' : '')
				+ (storm_reports_enabled ? '&stormReports=1' : '')
				+ (window.show_storm_reports ? '&showReports=1' : '')
				+ (storm_tracks_enabled ? '&stormTracks=1' : '')
				+ (window.show_storm_tracks ? '&showTracks=1' : '')
				+ (window.storm_chaser_enabled ? '&stormChasers=1' : '')
				+ (window.chasers_list_enabled ? '&chasersEnabled=1' : '')
				+ (window.storm_chaser_enabled && window.chaser ? '&chaser=' + window.chaser : '')
				+ (banner_enabled ? '' : '&hideBanner=1')
				+ (fullscreen_enabled ? '&fullscreen=2' : '')
				+ (lightning_enable ? '&lightning=1' : '')
				+ (temperature_enabled ? '&temperature=1' : '')
				+ (temperature_off ? '&temperature_off=1' : '')
				+ (windDirection_enabled ? '&windDirection=1' : '')
				+ (legend_enabled ? '&legend=1' : '')
				+ (windDirection_off ? '&windDirection_off=1' : '')
				+ (hide_logo ? '&hide_logo=1' : '')
				+ ('&satellite='+satellite_type)
				+ (window.video_ads_enabled ? '&vads=1' : '')
				+ (window.google_ads_enabled ? '&gads=1' : '')
				+ (window.google_ads_enabled ? '&gdelay=' + (window.google_ads_delay || 60) : '')
				+ (window.google_ads_enabled ? '&gpos=' + (window.google_ads_position || 'cc') : '')
				+ (autoloop_enabled ? '&autoloop=1' : '')
				+ (autorefresh_enabled ? '&autorefresh=1' : '')
				+ (show_zoomradar_banner ? '&show_zoomradar_banner=1' : '')
				+ (show_zoomradar_banner ? '&zoomradar_banner_timeout='+zoomradar_banner_timeout : '')
				+ '&locationDetect=0';

		if (typeof(detectLocation) != 'undefined') {
			if(mapKey){
				url += '&key='+mapKey;
			}
			url += '&locationRedirect=1';
		}

		// get custom logo filename only
		if (window.custom_logo != undefined) {
			// append logo to url
			url += '&lo=' + window.custom_logo.substring(window.custom_logo.lastIndexOf('/') + 1);
		}
		window.location = url;
	} else {
		if (typeof(zoomIncrease) != 'undefined') {
			GenerateMapPreview(zoomIncrease);
		} else {
			GenerateMapPreview();
		}
		if (addons) {
			for (var addon in addons) {
				addons[addon].updateCoordinates();
			}
		}
	}
}

function getWindowSize() {
	var myWidth = 0, myHeight = 0;
	if (typeof( window.innerWidth ) == 'number') {
		//Non-IE
		myWidth = window.innerWidth;
		myHeight = window.innerHeight;
	} else if (document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight )) {
		//IE 6+ in 'standards compliant mode'
		myWidth = document.documentElement.clientWidth;
		myHeight = document.documentElement.clientHeight;
	} else if (document.body && ( document.body.clientWidth || document.body.clientHeight )) {
		//IE 4 compatible
		myWidth = document.body.clientWidth;
		myHeight = document.body.clientHeight;
	}

	return {width: myWidth, height: myHeight};
}

function formatAMPM() {
	var date = new Date();
	var hours = date.getHours();
	var minutes = date.getMinutes();
	var ampm = hours >= 12 ? 'pm' : 'am';
	hours = hours % 12;
	hours = hours ? hours : 12; // the hour '0' should be '12'
	minutes = minutes < 10 ? '0'+minutes : minutes;
	var strTime = hours + ':' + minutes + ' ' + ampm;
	return strTime;
}

var panelTopPosition = 0;

/** Generates map preview. **/
function GenerateMapPreview(zoom_increase) {
	// Checks if it's iOS
	isIOS = (navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i)) || (navigator.userAgent.match(/iPad/i));
	$.support.cors = true;

	// autosize_onload: override width/height with screen size
	if (typeof(autosize_onload_enabled) != 'undefined' && autosize_onload_enabled) {

		var width = $(window).width();
		var height = $(window).height();

		if (width == 0 || height == 0) {
			var temp = getWindowSize();
			width = temp.width;
			height = temp.height;
		}

		if (width > 0 && height > 0) {
			map_width = width;
			map_height = height;

			$("#container").css({width: (typeof useResponsiveDesign != 'undefined' && useResponsiveDesign ? '100%' : map_width), height: map_height});
			//console.log('Autosize w=' + map_width + ', h=' + map_height);
		} else {
			//console.log('Autosize skipped: 0 width/height');
		}
	}

	//backup google ads
	$('#google-ads-popup').addClass('hide-ads');

	// Initializes container
	var containerInitalHTML = '';
	containerInitalHTML += '<div id="loading" style="display:none;background-image: url(img/blank.png);position:absolute;z-index:2;text-align: center;padding-top:10px;">Loading...</div>';
	containerInitalHTML += '<div id="radar_play_info" style="position:absolute;z-index:3;"></div>';
	containerInitalHTML += '<div id="zoomradar_banner" style="position:absolute; z-index:4; top: 30px; display: none;">';
	containerInitalHTML += '<a href="http://zoomradar.com/homepage/" target="_blank"><img src="img/zoomradar_banner.png"/></a>';
	containerInitalHTML += '<div style="position:absolute; z-index:5; top: 0px; left: 275px; cursor: pointer;">';
	containerInitalHTML += '<img id="close_zoomradar_banner" src="img/close-n.png"/>';
	containerInitalHTML += '</div></div>';
	containerInitalHTML += '<div id="zoomradar_banner" style="position:absolute;z-index:4;"></div>';
	containerInitalHTML += '<div id="zoomRadar_logo" style="position:absolute;display:none;z-index:3;'+((typeof top_left_logo != 'undefined' && top_left_logo) ? 'top: 30px;left:46px' : 'bottom:15px;right:5px')+'"></div>';
	containerInitalHTML += '<div id="fllscrn_bg" style="position:absolute;top:0px;left:0px;z-index:3;display:none;"></div>';
	containerInitalHTML += '<div id="search_bg" style="position:absolute;top:0px;left:0px;z-index:6;display:none;">';
	containerInitalHTML += '<img src="img/search-blue-bg.png" />';
	containerInitalHTML += '<div id="search_panel" style="position:absolute;top:3px;left:3px;z-index:6;display:none; background:url(img/search-box.png) no-repeat;padding:2px 30px 10px 35px;">';
	containerInitalHTML += '<input id="location_search" type="text" placehoder="enter ZIP code" name="location" style="border:none;background:none;width:100px;" />';
	containerInitalHTML += '</div>';
	containerInitalHTML += '</div>';
	containerInitalHTML += '<div id="zoom_bg" style="position:absolute;top:18px;left:0px;z-index:3;display:none;"><img src="' + (pan_enabled ? 'img/buttons-bg.png' : 'img/buttons-small-bg.png') + '" /></div>';
	containerInitalHTML += '<div id="animate_bg" style="position:absolute;top:135px;left:0px;z-index:3;display:none;">';
	containerInitalHTML += '<img src="img/animation-blue-bg.png" />';
	containerInitalHTML += '<div id="play_buttons" style="position:absolute;top:4px;left:4px;z-index:4;">';
	containerInitalHTML += '<img src="img/play-n.png" alt="play animation" id="play_animation" style="display:none;" />';
	containerInitalHTML += '<img src="img/stop-n.png" alt="stop animation" id="stop_animation" style="display:none;" />';
	containerInitalHTML += '</div>';
	containerInitalHTML += '</div>';
	containerInitalHTML += '<div id="legend-cont" style="position: absolute; width:280px; height:50px; left:100px; bottom:5px; z-index: 3; display: none;"><img src="img/map_legend_v2.png" /></div>';
	containerInitalHTML += '<div id="warn_bg" style="position:absolute;top:155px;left:0px;z-index:3;display:none;"><img src="img/warning-blue-bg.png" /></div>';
	containerInitalHTML += '<div id="warn_bg2" style="position:absolute;top:155px;left:0px;z-index:3;display:none;"><img src="img/warning-blue-bg.png" /></div>';
	containerInitalHTML += '<div id="wind_temperature_holder" style="width:40px;position:absolute;top:175px;left:0px;z-index:3;display:none;"></div>';
	containerInitalHTML += '<div id="legend_btn_holder" style="width:40px;position:absolute;top:155px;left:0px;z-index:3;display:none;"></div>';
	containerInitalHTML += '<div id="drag_bg" style="position:absolute;top:67px;left:40px;z-index:5;display:none;"><img src="img/drag-white-bg.png" /></div>';
	containerInitalHTML += '<div id="storm_reports_bg" style="position:absolute;top:155px;left:0px;z-index:3;display:none;"><img src="img/warning-blue-bg.png" /></div>';
	containerInitalHTML += '<div id="storm_tracks_bg" style="position:absolute;top:243px;left:0px;z-index:3;display:none;"><img src="img/warning-blue-bg.png" /></div>';
	containerInitalHTML += '<div id="lightning_bth" style="position:absolute;top:500px;left:0px;z-index:3;display:none;"><img src="img/warning-blue-bg.png" /></div>';
	containerInitalHTML += '<div id="share_bg" style="position:absolute;top:135px;left:0px;z-index:6;display:none;"></div>';
	containerInitalHTML += '<div id="map" style="z-index: 0; position: absolute; width:300px; height:300px;"></div>';
	containerInitalHTML += '<div id="status"></div><div id="map-loader" class="loader-map"></div>';
	
	if(typeof(opacitySlider) != 'undefined' && opacitySlider){
		containerInitalHTML += '<div id="slider"><div id="custom-handle" class="ui-slider-handle" style="position: absolute;"></div></div>';
	}
	$('#container').children(':not(#google-ads-popup):not(#ad_expanded):not(#ad_collapsed):not(#free_map_google_ads):not(#map):not(span)').remove();
	$('#container').append(containerInitalHTML);

	if(typeof(opacitySlider) != 'undefined' && opacitySlider){
		//Slider
		$( function() {
			var handle = $('#custom-handle');
			var slider = $('#slider').slider({
				min: 0,
				max: 100,
				range: "min",
				value: 75,
				create: function() {
					handle.text( $( this ).slider( "value" ) );
				},
				slide: function( event, ui ) {
					handle.text( ui.value );
					if(modules.nationalRadar) modules.nationalRadar.changeOpacity(ui.value/100);
				}
			});
		} );
	}

	// Init class FitMap
	$('#map').empty();
	$('#map').css({height: map_height, width: (typeof useResponsiveDesign != 'undefined' && useResponsiveDesign ? '100%' : map_width)});
	var latitude = lat - 0;
	var longitude = long - 0;
	var zoom_map = map_zoom - 0;
	if (typeof(zoom_increase) != 'undefined') {
		zoom_map = parseInt(zoom_increase);
	}
	var optionsLeaflet = {
		// theme: 'day',
		center: [latitude, longitude],
		zoom: zoom_map,
		zoomControl: false
	};

	window.zr_map = new LeafMap('map', optionsLeaflet);
	zr_map.onReady = mapReady;
	zr_map.init();
	window.map = zr_map.map;
	L.tileLayer('https://zoomradar-osm-tiles.s3.amazonaws.com/{z}/{x}/{y}.png', {
				maxZoom: 18,
				attribution: '&copy; <a href="http://www.openstreetmap.org/copyright">OpenStreetMap</a>',
				id: 'osm.mapnik'
			}).addTo(window.map);

	/** Adds event-listeners. **/
	// if (isIOS) {
		// zr_map.onTouchStart = onMapTouchStart;
		// zr_map.onTouchMove  = onMapTouchMove;
		// zr_map.onTouchEnd   = onMapTouchEnd;
	// } else {
		// zr_map.useWheel();
	// }

	zr_map.onZoom 	 	 = zoomEnd;
	zr_map.onDragStart 	 = dragStart;
	// zr_map.onDrag		 = dragging;
	zr_map.onDragEnd	 = dragEnd;
	zr_map.onIdle		 = mapIdle;

	// Initializes banner
	if (window.banner_enabled == undefined) banner_enabled = true;
	$('#radar_play_info').empty();
	$('#radar_play_info').css('right', 0);
	$('#radar_play_info').append('<div id="current_radar_label" style="color: white; font-size: 14px; font-weight: bold;  position: absolute; top: 1px; right: 2px; text-align: right; display: inline-block; background: linear-gradient(to right, rgba(45,92,169,0.1), rgba(45,92,169,0.8)); white-space: nowrap; padding-left: 25px;">Radar ' + formatAMPM()+ '</div>');
	$('#radar_play_info').hide();
	if (banner_enabled) $('#radar_play_info').show();

	if (window.show_zoomradar_banner == undefined) show_zoomradar_banner = false;
	if (window.zoomradar_banner_timeout == undefined || window.zoomradar_banner_timeout == 0){
		current_zoomradar_banner_timeout = 1;
	}else{
		current_zoomradar_banner_timeout = window.zoomradar_banner_timeout*1000;
	}
	if(show_zoomradar_banner){
		$('#zoomradar_banner').css('left', map_width - 300);

		$('#close_zoomradar_banner').mouseover(function(){
			$('#close_zoomradar_banner').attr("src", "img/close-sel.png");
		});
		$('#close_zoomradar_banner').mouseout(function(){
			$('#close_zoomradar_banner').attr("src", "img/close-n.png");
		});
		$('#close_zoomradar_banner').click(function(){
			$('#zoomradar_banner').hide();
		});
		window.setTimeout(function(){
			$('#zoomradar_banner').show();
		}, current_zoomradar_banner_timeout);
	}

	// Initializes logo
	var logoHeight = 50;
	if (window.logo_height != undefined && window.logo_height > 0)
		logoHeight = logo_height;
	if (window.custom_logo == undefined || !window.custom_logo || window.custom_logo == '') $("#zoomRadar_logo").html('<img src="img/map_zoomradar_logo_updated.png" />');
	else $("#zoomRadar_logo").html('<img src="' + custom_logo + '" style="max-height: '+logoHeight+'px" />');
	if(!hide_logo) $('#zoomRadar_logo').show();

	// Initializes loading screen
	$('#loading').css('width', map_width);
	$('#loading').css('height', map_height);

	//Stores panel's current top position
	var panelTopPosition = 0;

	// Initializes full screen button
	if (typeof(fullscreen_enabled) !== "undefined" && fullscreen_enabled) {
		var fullscreenButton;
		if (fullscreen_enabled == 2) {
			createPanelButton('fllscrn_bg', 'Restore Screen', 'img/restore-screen.png', 'img/restore-screen-s.png', function () {
				window.close();
			});
			if (navigator.userAgent.match(/(iPhone|iPod|iPad)/i)) {
				window.addEventListener('orientationchange', function () {
					if (fullscreen_enabled == 2) {
						window.close();
					}
				}, false);
			}
		} else {
			createPanelButton('fllscrn_bg', 'Fullscreen', 'img/fullscreen.png', 'img/full-screen-s.png', switchToFullScreen);
		}
		$('#fllscrn_bg').css('top', panelTopPosition);
		$('#fllscrn_bg').show();
		panelTopPosition += 40;
	}

	// Initializes search button
	if (search_enabled) {
		createPanelButton('search_bg', 'Search', 'img/search-n.png', 'img/search-sel.png', function () {
			if ($('#search_panel').is(':visible')) $('#search_panel').hide();
			else $('#search_panel').show();
		}, false, false, 3, 3);
		createPanelButton('search_panel', 'Go', 'img/search-arrow-n.png', 'img/search-arrow-sel.png', function () {
			if ($("#location_search").val() != ''){
				var geocode = new LocationGeocode();
				geocode.forward(address=$("#location_search").val()).then(function(data){
					if(data.length > 0){
						var info = data[0];
						lat = info.lat;
						long = info.lon;
						
						if(lat && long && window.zr_map){
							window.zr_map.setCenter({
								lat: lat, lng: long
							});

							window.zr_map.setZoom(getMinZoomLevel(9));
						}
					}
				})
			}
		}, false, false, 0, 132);
		$("#location_search").autocomplete("api.php?action=location", { width: 260, height: 260, selectFirst: true }).result(function (event, data, formatted) {
			if (!data) return;
		});
		$('#search_bg').css('top', panelTopPosition);
		$('#search_bg').show();
		panelTopPosition += 40;
	}

	// Initializes zoom buttons
	createPanelButton('zoom_bg', 'Zoom In', 'img/plus-n.png', 'img/plus-s.png', function () {
		zr_map.setZoom(getMinZoomLevel(zr_map.getZoom() + 1));
	}, true, false, 6, 4);
	createPanelButton('zoom_bg', 'Zoom Out', 'img/minus-n.png', 'img/minus-s.png', function () {
		zr_map.setZoom(getMinZoomLevel(zr_map.getZoom() - 1));
	}, true, false, 37, 4);
	$('#zoom_bg').css('top', panelTopPosition);
	if(typeof hidePlayButton != 'undefined'){
		$('#zoom_bg').css('top', '60px');
	}
	if(typeof hide_zoom != 'undefined' && hide_zoom){
	}else{
		$('#zoom_bg').show();
		panelTopPosition += 76;
	}

	// Initializes pan buttons
	if (pan_enabled) {
		createPanelButton('zoom_bg', 'Drag Controls', 'img/drag-n.png', 'img/drag-s.png', function () {
			if ($('#drag_bg').is(':visible')) $('#drag_bg').hide();
			else $('#drag_bg').show();
		}, true, false, 68, 4);
		createPanelButton('drag_bg', 'Move Left', 'img/drag-left-n.png', 'img/drag-left-s.png', function () {
			dragMapTo("left");
		}, true, false, 26, 4);
		createPanelButton('drag_bg', 'Move Right', 'img/drag-right-n.png', 'img/drag-right-s.png', function () {
			dragMapTo("right");
		}, true, false, 26, 55);
		createPanelButton('drag_bg', 'Move Up', 'img/drag-up-n.png', 'img/drag-up-s.png', function () {
			dragMapTo("up");
		}, true, false, 4, 27);
		createPanelButton('drag_bg', 'Move Down', 'img/drag-down-n.png', 'img/drag-down-s.png', function () {
			dragMapTo("down");
		}, true, false, 56, 27);
		createPanelButton('drag_bg', 'Close', 'img/drag-close-n.png', 'img/drag-close-s.png', function () {
			$('#drag_bg').hide();
		}, true, false, 30, 29);

		$('#drag_bg').css('top', panelTopPosition - 27);
		panelTopPosition += 31;
	}

	// Initializes animation button
	updateButtonStates('play_animation', 'img/play-n.png', 'img/play-sel.png', function () {
		modules.nationalRadar.startAnimation();
	});
	updateButtonStates('stop_animation', 'img/stop-n.png', 'img/stop-sel.png', function () {
		modules.nationalRadar.stopAnimation();
		$('#map-loader').hide();
	});
	if (!autoloop_enabled) {
		$('#play_animation').show();
		$('#stop_animation').hide();
	} else {
		$('#play_animation').hide();
		$('#stop_animation').show();
	}
	$('#animate_bg').css('top', panelTopPosition);
	if (typeof hidePlayButton == 'undefined') {
		$('#animate_bg').show();
		panelTopPosition += 40;
	}

	// Initializes warnings button
	if (warnings_enabled) {
		var allWarningsPrefix = (typeof allWarnings_enabled != 'undefined' && allWarnings_enabled) ? 'all-' : '';
		createPanelButton('warn_bg', 'Severe Warnings', 'img/warning-n.png', 'img/warning-sel.png', function () {
			addons.severeWarnings.hideWarnings();
			addons.severeWarnings.mainWarningsEnabled = !addons.severeWarnings.mainWarningsEnabled;
			addons.severeWarnings.showWarnings();
		}, false, true, 6, 4);
		$('#warn_bg').css('top', panelTopPosition);
		$('#warn_bg').show();

		if(typeof allWarnings_enabled != 'undefined' && allWarnings_enabled){
			panelTopPosition += 45;
			createPanelButton('warn_bg2', 'Other Alerts', 'img/all-warning-n.png', 'img/all-warning-sel.png', function () {
				addons.severeWarnings.hideWarnings();
				addons.severeWarnings.allWarningsEnabled = !addons.severeWarnings.allWarningsEnabled;
				addons.severeWarnings.showWarnings();
			}, false, (typeof displayBulletins != 'undefined' && displayBulletins), 6, 4);
			$('#warn_bg2').css('top', panelTopPosition);
			$('#warn_bg2').show();

			if (typeof alertHint !== 'undefined' && alertHint) {
				$('#warn_bg2').append('<div class="sc-tip" style="top: -13px; left: 100%;"><a href="#" title="Close" class="close">X</a><p class="sc-tip-msg" style="width: 128px;">Click this yellow triangle for Active Watches and Advisories</p></div>');

				$('#warn_bg2').find('.close').on('click', function() {
					$(this).parent().css('opacity', 1).fadeTo(350, 0, function() {
						$(this).remove();
					});
				});
			}
		}

		function showWarnings(){
			if(addons.severeWarnings){
				addons.severeWarnings.mainWarningsEnabled = true;
				addons.severeWarnings.allWarningsEnabled = (typeof displayBulletins != 'undefined' && displayBulletins);
				addons.severeWarnings.showWarnings();
			} else {
				setTimeout(showWarnings, 1000);
			}
		}

		showWarnings();

		panelTopPosition += 45;
	}

	// Initializes temperatures button
	if (temperature_enabled) {
		createPanelButton('wind_temperature_holder', 'Temperature', 'img/current-temp-paused.png', 'img/current-temp-selected.png', function () {
			if (!temperaturesEnabled) {
				temperaturesEnabled = true;
				addons.temperaturesAndWinds.enableTemperatures();
			} else {
				temperaturesEnabled = false;
				addons.temperaturesAndWinds.disableTemperatures();
			}
		}, false, false, 0, 0);
		$('#wind_temperature_holder').css('top', panelTopPosition);
		$('#wind_temperature_holder').show();

		function enableTemperatures(){
			temperaturesEnabled = true;
			if(addons.temperaturesAndWinds){
				addons.temperaturesAndWinds.enableTemperatures();
			} else {
				setTimeout(enableTemperatures, 1000);
			}
		}
		if(!temperature_off)
			enableTemperatures();

		panelTopPosition += 45;
	}


		// Initializes wind directions button
		if (windDirection_enabled) {
			createPanelButton('wind_temperature_holder', 'Wind Direction', 'img/wind-speed-paused.png', 'img/wind-speed-selected.png', function () {
				if (!windDirectionsEnabled) {
					windDirectionsEnabled = true;
					addons.temperaturesAndWinds.enableWindDirections();
				} else {
					windDirectionsEnabled = false;
					addons.temperaturesAndWinds.disableWindDirections();
				}
			}, false, false, temperature_enabled ? 45 : 0, 0);
			if (!temperature_enabled) {
				$('#wind_temperature_holder').css('top', panelTopPosition);
				$('#wind_temperature_holder').show();
			}

			function enableWindDirections(){
				windDirectionsEnabled = true;
				if(addons.temperaturesAndWinds){
					addons.temperaturesAndWinds.enableWindDirections();
				} else {
					setTimeout(enableWindDirections, 1000);
				}
			}
			if(!windDirection_off)
				enableWindDirections();

			panelTopPosition += 45;
		}

		// Initializes Legend button
		if (typeof(legend_enabled) != 'undefined' && legend_enabled) {
			$('#legend-cont').css('display', 'block');

			createPanelButton('legend_btn_holder', 'Legend', 'img/info_label_n.png', 'img/info_label_s.png', function () {
				if (!legendEnabled) {
					legendEnabled = true;
					$('#legend-cont').css('display', 'block');
				} else {
					legendEnabled = false;
					$('#legend-cont').css('display', 'none');
				}
			}, false, true, 0, 0);
			$('#legend_btn_holder').css('top', panelTopPosition);
			$('#legend_btn_holder').show();

			panelTopPosition += 45;
		}

		// Initializes storm reports button
		if (storm_reports_enabled) {
			createPanelButton('storm_reports_bg', 'Storm Reports', 'img/storm-reports-n.png', 'img/storm-reports-sel.png', function () {

			 if (!stormRepordsEnabled) {
					stormRepordsEnabled = true;
					addons.stormReports.showReports(true);

				} else {
					stormRepordsEnabled = false;
					addons.stormReports.showReports(false);
				}
			}, false, show_storm_reports, 3, 3);
			$('#storm_reports_bg').css('top', panelTopPosition);
			$('#storm_reports_bg').show();
			stormRepordsEnabled = show_storm_reports; //jeff request -> should false by default

			if(stormRepordsEnabled){
				function showStormReports(){
					if(addons.stormReports){
						addons.stormReports.showReports(true);
					} else {
						setTimeout(showStormReports, 1000);
					}
				}
				showStormReports();
			}

			panelTopPosition += 45;
		}
		// Initializes storm tracks button
		if (storm_tracks_enabled) {
			createPanelButton('storm_tracks_bg', 'Storm Tracks', 'img/storm-track_n.png', 'img/storm-track_s.png', function () {
				if (!stormTracksEnabled) {
					stormTracksEnabled = true;
					addons.stormTracks.toggleTracks(true);
				} else {
					stormTracksEnabled = false;
					addons.stormTracks.toggleTracks(false);
				}
			}, false, false, 3, 3);
			$('#storm_tracks_bg').css('top', panelTopPosition);
			$('#storm_tracks_bg').show();

			stormTracksEnabled = show_storm_tracks;

			if(stormTracksEnabled){
				function showStormTracks(){
					if(addons.stormTracks){
						addons.stormTracks.showTracks(true);
					} else {
						setTimeout(showStormTracks, 1000);
					}
				}
				showStormTracks();
			}

			panelTopPosition += 45;
		}

		if (window.storm_chaser_enabled) {
			setTimeout(function () {
				if(addons.stormChaser){
					addons.stormChaser.enableStormChaser(storm_chaser_enabled);
				}
			}, 1000);
		}

		// Initializes lightnings
		if(lightning_enable){
			var activeImage1 = !autoLightningEnable? 'img/lightning_n.png': 'img/lightning_s.png';
			var image2 = autoLightningEnable? 'img/lightning_n.png': 'img/lightning_s.png';
			var lAlt = '';

			function enableAutoLightning () {
				addons.lightning.getLightningsInit();
				addons.lightning.startObservation();
				lAlt = $('#img_lightning_bth').attr('alt');
				$('#img_lightning_bth').attr('title', 'GLM ' + lAlt);
				setTimeout(function(){
					$('#img_lightning_bth').attr('title', 'GLM ' + lAlt + ' via NASA');
				}, 20100);
			}

			createPanelButton('lightning_bth', 'Lightning: 20 Second Updates', activeImage1, image2,
			function () {
				if (!autoLightningEnable) {
					autoLightningEnable = true;
					enableAutoLightning();
				} else {
					autoLightningEnable = false;
					addons.lightning.stopObservation();
					$('#img_lightning_bth').attr('title', lAlt);
				}
			},
			false, false, 6, 4);
			if(autoLightningEnable) {
				function enAutoLightBtn() {
					if(addons.lightning){
						enableAutoLightning();
					} else {
						setTimeout(enAutoLightBtn, 1000);
					}
				};
				enAutoLightBtn();
			}
			$('#lightning_bth').css('top', panelTopPosition);
			$('#lightning_bth').show();
			panelTopPosition += 45;
		}

		// Initializes share button
		createPanelButton('share_bg', 'Share Radar Movie on Facebook', 'img/share-btn-small.png', 'img/share-btn-s-small.png', function () {
			var leftPointLat = zr_map.getBoundsN();
			var leftPointLng = zr_map.getBoundsW();
			var rightPointLat = zr_map.getBoundsS();
			var rightPointLng = zr_map.getBoundsE();
			window.open('zoomRadar_share.php?lpLat=' + leftPointLat + '&lpLng=' + leftPointLng + '&rpLat=' + rightPointLat + '&rpLng=' + rightPointLng + '&w=' + map_width + '&h=' + map_height + '&map=' + zr_map.getCenterLat() + '_' + zr_map.getCenterLon() + '_' + zr_map.getZoom() + '&sitep=' + $('#upload_title').val());
		}, true, false, 0, 0);
		$('#share_bg').css('top', map_height - 43);
		$('#share_bg').css('left', map_width - 35);
		// Temporary disabling share button
		// $('#share_bg').show();

		// Initializes ads
		if (ads_enabled) {
			if (map_width == 290)
				$('#map').append('<div id="zoomradar_ads" class="list"><a href="http://www.zoomradar.com" target="_blank"><img src="img/banner_300_2.png"/></a></div>');
			else if (map_width == 250)
				$('#map').append('<div id="zoomradar_ads" class="list"><a href="http://www.zoomradar.com" target="_blank"><img src="img/ad-map03_small.png"/></a></div>');
		}

		// Google ads
		if(window.google_ads_enabled){

			//dynamic load the ads
			$('#google-ads-popup')
					.find('.close-ads').unbind('click').click(function(){
						$('#google-ads-popup').addClass('hide-ads');
						return false;
			});  //hide by default

			setTimeout(function(){
				//check for the ads
				var ads_popup = $('#google-ads-popup');
				if(!ads_popup.length){
					return;
				}

				//reset
				ads_popup.css({
					top: '',
					left: ''
				});

				//set the position
				if(window.google_ads_position.indexOf(',') !== -1){
					var pos = window.google_ads_position.split(',');
					pos[0] = parseInt(pos[0]);
					pos[1] = parseInt(pos[1]);

					if(isNaN(pos[0]) || isNaN(pos[1])){
						ads_popup.addClass('cc');
					} else {
						ads_popup.css({
							left: pos[0],
							top: pos[1]
						});
					}

				} else {
					ads_popup.removeClass('cc').addClass(window.google_ads_position);
				}

				if(ads_popup.hasClass('cc')){
					ads_popup.css({
						marginLeft: -(window.google_ad_width || 300) / 2,
						marginTop: -(window.google_ad_height || 250) / 2
					});
				}

				//show the popup
				ads_popup.removeClass('hide-ads');

			}, (parseInt(window.google_ads_delay) || 60) * 1000);
		}

		// Main ads
		if(window.main_ads_enabled && !window.google_ads_enabled){

			//dynamic load the ads
			$('#google-ads-popup')
					.find('.close-ads').unbind('click').click(function(){
				$('#google-ads-popup').addClass('hide-ads');
				return false;
			});  //hide by default

			var ads_popup = $('#google-ads-popup');
			if(!ads_popup.length){
				return;
			}

			//reset
			ads_popup.css({
				top: '',
				left: ''
			});

			//set the position
			ads_popup.addClass('cc');
			ads_popup.css({
				marginLeft: -(window.google_ad_width || 300) / 2,
				marginTop: -(window.google_ad_height || 250) / 2
			});

			//show the popup
			ads_popup.removeClass('hide-ads');
		}

		/** Creates panel button. **/
		function createPanelButton(buttonContainer, title, src, srcOver, onClick, disableSelection, selected, top, left) {
			// Default values
			disableSelection = disableSelection | false;
			selected = selected | false;
			top = top | 0;
			left = left | 0;

			var button = document.createElement("img");
			button.style.position = "absolute";
			button.style.zIndex = "50";
			button.style.top = "" + top + "px";
			button.style.left = "" + left + "px";
			button.alt = title;
			button.title = title;
			if (selected)
				button.src = srcOver;
			else
				button.src = src;
			var buttonSelected = selected;
			button.onmouseover = function () {
				this.src = srcOver;
			};
			button.onmouseout = function () {
				if (!buttonSelected)
					this.src = src;
			};
			button.onclick = function () {
				if (!disableSelection) {
					buttonSelected = !buttonSelected;
					if (!buttonSelected)
						this.src = src;
					else
						this.src = srcOver;
				}
				onClick();
			};
			document.getElementById(buttonContainer).appendChild(button);
		}

		/** Drags map to a direction. **/
		function dragMapTo(direction) {
			var latDelta = (zr_map.getBoundsN() - zr_map.getBoundsS()) / 4;
			var lngDelta = (zr_map.getBoundsE() - zr_map.getBoundsW()) / 4;

			var center_lat = zr_map.getCenterLat();
			var center_lng = zr_map.getCenterLon();
			switch (direction) {
				case "up":
					center_lat += latDelta;
					break;
				case "right":
					center_lng += lngDelta;
					break;
				case "down":
					center_lat -= latDelta;
					break;
				case "left":
					center_lng -= lngDelta;
					break;
			}
			zr_map.setCenter({lat: center_lat, lng: center_lng});
			inputUpdateTimeout = setTimeout(function () {
				for (var module in modules) {
					modules[module].refresh();
				}
			}, 1000);
		}

		/** Creates panel button. **/
		function updateButtonStates(buttonId, src, srcOver, onClick) {
			var button = document.getElementById(buttonId);
			button.onmouseover = function () {
				this.src = srcOver;
			};
			button.onmouseout = function () {
				this.src = src;
			};
			button.onclick = function () {
				onClick();
			};
		}

		/**
		 * Return screen width and height.
		 */
		function getScreenSize() {
			var screenW = 640, screenH = 480;
			if (parseInt(navigator.appVersion) > 3) {
				screenW = screen.width;
				screenH = screen.height;
			} else if (navigator.appName == "Netscape" && parseInt(navigator.appVersion) == 3 && navigator.javaEnabled()) {
				var jToolkit = java.awt.Toolkit.getDefaultToolkit();
				var jScreenSize = jToolkit.getScreenSize();
				screenW = jScreenSize.width;
				screenH = jScreenSize.height;
			}

			return {width: screenW, height: screenH};
		}

		/** Switchs to full screen. **/
		function switchToFullScreen() {

			var screenSize = getScreenSize();

			var url = BASE_URL + 'weather_page.php?fullscreenMode=1&key=' + mapKey
					+ '&w=' + screenSize.width + '&h=' + screenSize.height
					+ '&z=' + zr_map.getZoom()
					+ '&lat=' + zr_map.getCenterLat()
					+ '&lng=' + zr_map.getCenterLon();
					if(!mapKey)
				url += ''
					+ (pan_enabled ? '&pan=1' : '&pan=0')
					+ (search_enabled ? '&search=1' : '')
					+ (warnings_enabled ? '&warn=1' : '')
					+ (bulletins_enabled ? '&bulletins=1' : '')
					+ (allWarnings_enabled ? '&allWarn=1' : '')
					+ (storm_reports_enabled ? '&stormReports=1' : '')
					+ (window.show_storm_reports ? '&showReports=1' : '')
					+ (storm_tracks_enabled ? '&stormTracks=1' : '')
					+ (window.show_storm_tracks ? '&showTracks=1' : '')
					+ (window.storm_chaser_enabled ? '&stormChasers=1' : '')
					+ (window.chasers_list_enabled ? '&chasersEnabled=1' : '')
					+ (window.storm_chaser_enabled && window.chaser ? '&chaser=' + window.chaser : '')
					+ (banner_enabled ? '' : '&hideBanner=1')
					+ (temperature_enabled ? '&temperature=1' : '')
					+ (temperature_off ? '&temperature_off=1' : '')
					+ (lightning_enable ? '&lightning=1' : '')
					+ (windDirection_enabled ? '&windDirection=1' : '')
					+ ((typeof(legend_enabled) != 'undefined' && legend_enabled) ? '&legend=1' : '')
					+ (windDirection_off ? '&windDirection_off=1' : '')
					+ (hide_logo ? '&hide_logo=1' : '')
					+ ('&satellite='+satellite_type)
					+ (autoloop_enabled ? '&autoloop=1' : '')
					+ (autorefresh_enabled ? '&autorefresh=1' : '')
					+ (show_zoomradar_banner ? '&show_zoomradar_banner=1' : '')
					+ (show_zoomradar_banner ? '&zoomradar_banner_timeout='+zoomradar_banner_timeout : '')
					+ (window.map_ads ? '&mapads=' + window.map_ads : '')
					+ ((typeof(opacitySlider) != 'undefined' && opacitySlider) ? '&opacity=1' : '')
					+ '&sitep=' + $('#upload_title').val();

			// get custom logo filename only
			if (window.custom_logo != undefined) {
				// append logo to url
				url += '&lo=' + window.custom_logo.substring(window.custom_logo.lastIndexOf('/') + 1);
			}
			window.open(url, '', 'width=' + screenSize.width + ',height=' + screenSize.height);
		}

		if(exclude_all_buttons){
			if($('#fllscrn_bg')[0]) $('#fllscrn_bg').hide();
			if($('#search_bg')[0]) $('#search_bg').hide();
			if($('#zoom_bg')[0]) $('#zoom_bg').hide();
			if($('#play_buttons')[0]) $('#play_buttons').hide();
			if($('#animate_bg')[0]) $('#animate_bg').hide();
			if($('#warn_bg')[0]) $('#warn_bg').hide();
			if($('#wind_temperature_holder')[0]) $('#wind_temperature_holder').hide();
			if($('#legend_btn_holder')[0]) $('#legend_btn_holder').hide();
			if($('#drag_bg')[0]) $('#drag_bg').hide();
			if($('#storm_reports_bg')[0]) $('#storm_reports_bg').hide();
			if($('#storm_tracks_bg')[0]) $('#storm_tracks_bg').hide();
		}

		function mapReady() {
			//console.log("Main: mapReady()");
			//Registers zoom level
			zoomLevel = zr_map.getZoom();

			/** Enables modules. **/
			initiateModules(zr_map);

			/** Enables add-ons. **/
			initiateAddons(zr_map);

			/** Enables add-ons. **/
			if (autoloop_enabled) {
				setTimeout(function () {
					modules.nationalRadar.startAnimation();
				}, 5000);
			}

			if(drop_center_pin){
				var iconUrl = (('https:' === document.location.protocol) ? 'https' : 'http')+'://builder.zoomradar.net/zoomradar_weather_map/img/center-pin2.png';
				zr_map.placeCustomMarker(latitude, longitude, iconUrl, 20, 34);
			}
		}
}

/** Modules holder, parameters and initiator. **/

var modules = {};

var moduleParameters = {
	nationalRadar: {
		path: 'national_radar',
		map: null,
		feedUrl: 'national.php',
		tileUrl: (('https:' == document.location.protocol) ? 'https' : 'http')+'://miami.zoomradar.net/HiResNationalRadar3/',
		tileCoordinatesUrl: null,
		radarSize: {
			width: 14200,
			height: 7956
		},
		maxZoomLevel: 16,
		autoLoop: (typeof autoloop_enabled != 'undefined') ? autoloop_enabled : false,
		autoRefresh: (typeof autorefresh_enabled != 'undefined') ? autorefresh_enabled : false,
		ignoreRadar: (typeof ignore_radar != 'undefined') ? ignore_radar : false,
		useAllFrames: (typeof useAllFrames != 'undefined' && useAllFrames) ? true : false,
		skipSomeFrames: (typeof skipSomeFrames != 'undefined' && !skipSomeFrames) ? false : true
	}
};

if(useLargeFeed) {
	moduleParameters.nationalRadar.feedUrl = 'national.php?newMosaic=1';
	moduleParameters.nationalRadar.tileUrl = (('https:' == document.location.protocol) ? 'https' : 'http')+'://miami.zoomradar.net/HiResNationalRadar4/';
	moduleParameters.nationalRadar.tileCoordinatesUrl = 'national_tile_coordinates.json';
	moduleParameters.nationalRadar.radarSize = {
		width: 28431,
		height: 15919
	};
	moduleParameters.nationalRadar.maxZoomLevel = 64;
}

/** Initiates modules. **/
function initiateModules(map) {
	var modulesCount = 0;
	for (var module in moduleParameters)
		modulesCount++;

	var modulesLoaded = 0;

	function moduleLoaded() {
		modulesLoaded++;
		if (modulesLoaded == modulesCount) {
			for (var module in modules) {
				modules[module].init(moduleParameters[module]);
			}
		}
	}

	for (var module in moduleParameters) {
		moduleParameters[module].map = map;
		$.getScript('modules_leaflet/' + moduleParameters[module].path + '.js?c=' + cacheNumber)
		.done(function( script, textStatus ) {
			//console.log( 'Module loaded ' + textStatus );
			moduleLoaded();
		})
		.fail(function( jqxhr, settings, exception ) {
			console.log('Module error');
			console.log('jqxhr ', jqxhr);
			console.log('settings ', settings);
			console.log('exception ', exception);
		});
	}
}

var addons = {};

/** Initiates add-ons. **/
function initiateAddons(map) {
	var addonsCount = 0;
	var addonsLoaded = 0;

	var addonParameters = {
		severeWarnings: {
			path: 'severe_warnings',
			map: null,
			showWarnings: false,
			feedUrl: 'alerts2.php',
			infoUrl: 'warning.php'
		},
		stormReports: {
			path: 'storm_reports',
			map: null,
			showReports: window.show_storm_reports || false,
			feedUrl: 'storm_reports.php'
		},
		stormTracks: {
			path: 'storm_tracks',
			map: null,
			showTracks: window.show_storm_tracks || false,
			feedUrl: 'storm_tracks.php',
		},
		temperaturesAndWinds: {
			path: 'temperatures_and_winds',
			map: null,
			showTemperatures: false,
			showWindDirections: false,
			feedUrl: 'getTemp.php',
			moreData: (typeof more_temps_and_winds != 'undefined') ? more_temps_and_winds : false
		},
		stormChaser: {
			path: 'storm_chaser',
			map: null,
			flowplayer_adds: window.flowplayer_adds,
			flowplayer_adds_delay: window.flowplayer_adds_delay,
			enableStormChaser: window.storm_chaser_enabled || false,
			enableVideoAds: window.video_ads_enabled || false,
			showStormChaser: true,
			chaser: window.chaser,
			chasersListEnabled: (typeof window.chasers_list_enabled != 'undefined' && window.chasers_list_enabled),
			feedUrl: 'sc_updater.php?hiload=2',
		},
		constructionPins: {
			path: 'construction_pins',
			map: null,
			enableConstructionPins: (typeof autorefresh_enabled != 'undefined') ? constructionPins_enabled : false,
			constructionLocations: (typeof autorefresh_enabled != 'undefined') ? constructionLocations : []
		},
		lightning: {
			path: 'lightning',
			map: null,
			feedUrl: 'get_lightnings.php',
			getCoordinatesURL: 'getLightningsCoordinates.php'
		}
	};

	for (var addon in addonParameters) {
		addonsCount++;
	}

	function addonLoaded() {
		addonsLoaded++;
		if (addonsLoaded == addonsCount) {
			for (var addon in addons) {
				addons[addon].init(addonParameters[addon]);
			}
		}
	}

	for (var addon in addonParameters) {
		addonParameters[addon].map = map;
		$.getScript('addons_leaflet/' + addonParameters[addon].path + '.js?c='+ cacheNumber)
		.done(function( script, textStatus ) {
    	//console.log( 'Addon loaded ' + textStatus );
			addonLoaded();
  	})
  	.fail(function( jqxhr, settings, exception ) {
			console.log('Addon error');
    		console.log('jqxhr ', jqxhr);
			console.log('settings ', settings);
			console.log('exception ', exception);
		});
	}
}

// =====================================================================================================================
// geolocation
var locationBrowser = null;

function doDetectLocation() {

	// Check to see if this browser supports geolocation.
	if (!navigator.geolocation) {
		console.log("NOTICE: Browser does not allow to detect location");
		return;
	}

	// Get the location of the user's browser using the
	// native geolocation service. When we invoke this method
	// only the first callback is required. The second
	// callback - the error handler - and the third
	// argument - our configuration options - are optional.
	navigator.geolocation.getCurrentPosition(
			function (position) {

				// Check to see if there is already a location.
				// There is a bug in FireFox where this gets
				// invoked more than once with a cached result.
				if (locationBrowser) {
					return;
				}

				// Log that this is the initial position.
				console.log("Initial Position Found");

				// Store position.
				locationBrowser = position;

				// Update lat/long
				lat = position.coords.latitude;
				long = position.coords.longitude;

				// Store in cookies to avoid detection on page refresh
				createCookie('zrwm_geolocation', lat + '|' + long, 60);

				updateMapOnLocationChange(true, undefined, true);
			},
			function (error) {
				console.log("ERROR: Cannot detect location, something went wrong: ", error);
				location.href = location.href+"&failedGps=1";
			},
			{
				timeout: (30 * 1000),
				maximumAge: 0, //(1000 * 60 * 15),
				enableHighAccuracy: true
			}
	);

}

// =====================================================================================================================
// geolocation
var locationBrowser = null;

function doDetectLocation() {

	// Check to see if this browser supports geolocation.
	if (!navigator.geolocation) {
		console.log("NOTICE: Browser does not allow to detect location");
		return;
	}

	// Get the location of the user's browser using the
	// native geolocation service. When we invoke this method
	// only the first callback is required. The second
	// callback - the error handler - and the third
	// argument - our configuration options - are optional.
	navigator.geolocation.getCurrentPosition(
			function (position) {

				// Check to see if there is already a location.
				// There is a bug in FireFox where this gets
				// invoked more than once with a cached result.
				if (locationBrowser) {
					return;
				}

				// Log that this is the initial position.
				console.log("Initial Position Found");

				// Store position.
				locationBrowser = position;

				// Update lat/long
				lat = position.coords.latitude;
				long = position.coords.longitude;

				// Store in cookies to avoid detection on page refresh
				createCookie('zrwm_geolocation', lat + '|' + long, 60);

				updateMapOnLocationChange(true, undefined, true);
			},
			function (error) {
				console.log("ERROR: Cannot detect location, something went wrong: ", error);
				location.href = location.href+"&failedGps=1";
			},
			{
				timeout: (30 * 1000),
				maximumAge: 0, //(1000 * 60 * 15),
				enableHighAccuracy: true
			}
	);

}

function getMinZoomLevel(newZoomLevel){
	if(typeof minZoomLevel != 'undefined'){
		return Math.max(minZoomLevel, newZoomLevel);
	}
	return newZoomLevel;
}

function checkMinZoomLevel(){
	if(typeof minZoomLevel != 'undefined' && zr_map.map.getZoom() < minZoomLevel){
		zr_map.map.setZoom(minZoomLevel);
	}
}

function createCookie(name, value, days) {
	if (days) {
		var date = new Date();
		date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
		var expires = "; expires=" + date.toGMTString();
	}
	else var expires = "";
	document.cookie = name + "=" + value + expires + "; path=/";
}
